==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Recepta.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.OddzialNFZ;
import pl.topteam.dps.enums.UprawnieniaChPrzewlekle;
import pl.topteam.dps.enums.UprawnienieLeki;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Recepta extends GenericDPSObject {
    /**
     * RECEPTA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * RECEPTA.EWIDENCJA_DPS_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ewidencjaDpsId;

    /**
     * RECEPTA.LEKARZ_WYSTAWIL_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long lekarzWystawilId;

    /**
     * RECEPTA.CHOROBY_PRZEWLEKLE
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private UprawnieniaChPrzewlekle chorobyPrzewlekle;

    /**
     * RECEPTA.DATA_WYSTAWIENIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWystawienia;

    /**
     * RECEPTA.ODDZIAL_NFZ
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private OddzialNFZ oddzialNfz;

    /**
     * RECEPTA.UPRAWNIENIE
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private UprawnienieLeki uprawnienie;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return RECEPTA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * RECEPTA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return RECEPTA.EWIDENCJA_DPS_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getEwidencjaDpsId() {
        return ewidencjaDpsId;
    }

    /**
     * RECEPTA.EWIDENCJA_DPS_ID
     *
     * @param ewidencjaDpsId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEwidencjaDpsId(Long ewidencjaDpsId) {
        this.ewidencjaDpsId = ewidencjaDpsId;
    }

    /**
     * @return RECEPTA.LEKARZ_WYSTAWIL_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getLekarzWystawilId() {
        return lekarzWystawilId;
    }

    /**
     * RECEPTA.LEKARZ_WYSTAWIL_ID
     *
     * @param lekarzWystawilId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setLekarzWystawilId(Long lekarzWystawilId) {
        this.lekarzWystawilId = lekarzWystawilId;
    }

    /**
     * @return RECEPTA.CHOROBY_PRZEWLEKLE
     * @mbggenerated 2014-03-10 10:45:37
     */
    public UprawnieniaChPrzewlekle getChorobyPrzewlekle() {
        return chorobyPrzewlekle;
    }

    /**
     * RECEPTA.CHOROBY_PRZEWLEKLE
     *
     * @param chorobyPrzewlekle
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setChorobyPrzewlekle(UprawnieniaChPrzewlekle chorobyPrzewlekle) {
        this.chorobyPrzewlekle = chorobyPrzewlekle;
    }

    /**
     * @return RECEPTA.DATA_WYSTAWIENIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWystawienia() {
        return dataWystawienia;
    }

    /**
     * RECEPTA.DATA_WYSTAWIENIA
     *
     * @param dataWystawienia
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWystawienia(Date dataWystawienia) {
        this.dataWystawienia = dataWystawienia;
    }

    /**
     * @return RECEPTA.ODDZIAL_NFZ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public OddzialNFZ getOddzialNfz() {
        return oddzialNfz;
    }

    /**
     * RECEPTA.ODDZIAL_NFZ
     *
     * @param oddzialNfz
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOddzialNfz(OddzialNFZ oddzialNfz) {
        this.oddzialNfz = oddzialNfz;
    }

    /**
     * @return RECEPTA.UPRAWNIENIE
     * @mbggenerated 2014-03-10 10:45:37
     */
    public UprawnienieLeki getUprawnienie() {
        return uprawnienie;
    }

    /**
     * RECEPTA.UPRAWNIENIE
     *
     * @param uprawnienie
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setUprawnienie(UprawnienieLeki uprawnienie) {
        this.uprawnienie = uprawnienie;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Recepta other = (Recepta) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaDpsId() == null ? other.getEwidencjaDpsId() == null : this.getEwidencjaDpsId().equals(other.getEwidencjaDpsId()))
            && (this.getLekarzWystawilId() == null ? other.getLekarzWystawilId() == null : this.getLekarzWystawilId().equals(other.getLekarzWystawilId()))
            && (this.getChorobyPrzewlekle() == null ? other.getChorobyPrzewlekle() == null : this.getChorobyPrzewlekle().equals(other.getChorobyPrzewlekle()))
            && (this.getDataWystawienia() == null ? other.getDataWystawienia() == null : this.getDataWystawienia().equals(other.getDataWystawienia()))
            && (this.getOddzialNfz() == null ? other.getOddzialNfz() == null : this.getOddzialNfz().equals(other.getOddzialNfz()))
            && (this.getUprawnienie() == null ? other.getUprawnienie() == null : this.getUprawnienie().equals(other.getUprawnienie()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaDpsId() == null) ? 0 : getEwidencjaDpsId().hashCode());
        result = prime * result + ((getLekarzWystawilId() == null) ? 0 : getLekarzWystawilId().hashCode());
        result = prime * result + ((getChorobyPrzewlekle() == null) ? 0 : getChorobyPrzewlekle().hashCode());
        result = prime * result + ((getDataWystawienia() == null) ? 0 : getDataWystawienia().hashCode());
        result = prime * result + ((getOddzialNfz() == null) ? 0 : getOddzialNfz().hashCode());
        result = prime * result + ((getUprawnienie() == null) ? 0 : getUprawnienie().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaDpsId=").append(ewidencjaDpsId);
        sb.append(", lekarzWystawilId=").append(lekarzWystawilId);
        sb.append(", chorobyPrzewlekle=").append(chorobyPrzewlekle);
        sb.append(", dataWystawienia=").append(dataWystawienia);
        sb.append(", oddzialNfz=").append(oddzialNfz);
        sb.append(", uprawnienie=").append(uprawnienie);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Recepta.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.OddzialNFZ;
import pl.topteam.dps.enums.UprawnieniaChPrzewlekle;
import pl.topteam.dps.enums.UprawnienieLeki;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Recepta extends GenericDPSObject {
    /**
     * RECEPTA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * RECEPTA.EWIDENCJA_DPS_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ewidencjaDpsId;

    /**
     * RECEPTA.LEKARZ_WYSTAWIL_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long lekarzWystawilId;

    /**
     * RECEPTA.CHOROBY_PRZEWLEKLE
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private UprawnieniaChPrzewlekle chorobyPrzewlekle;

    /**
     * RECEPTA.DATA_WYSTAWIENIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWystawienia;

    /**
     * RECEPTA.ODDZIAL_NFZ
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private OddzialNFZ oddzialNfz;

    /**
     * RECEPTA.UPRAWNIENIE
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private UprawnienieLeki uprawnienie;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return RECEPTA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * RECEPTA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return RECEPTA.EWIDENCJA_DPS_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getEwidencjaDpsId() {
        return ewidencjaDpsId;
    }

    /**
     * RECEPTA.EWIDENCJA_DPS_ID
     *
     * @param ewidencjaDpsId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEwidencjaDpsId(Long ewidencjaDpsId) {
        this.ewidencjaDpsId = ewidencjaDpsId;
    }

    /**
     * @return RECEPTA.LEKARZ_WYSTAWIL_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getLekarzWystawilId() {
        return lekarzWystawilId;
    }

    /**
     * RECEPTA.LEKARZ_WYSTAWIL_ID
     *
     * @param lekarzWystawilId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setLekarzWystawilId(Long lekarzWystawilId) {
        this.lekarzWystawilId = lekarzWystawilId;
    }

    /**
     * @return RECEPTA.CHOROBY_PRZEWLEKLE
     * @mbggenerated 2014-03-13 16:02:38
     */
    public UprawnieniaChPrzewlekle getChorobyPrzewlekle() {
        return chorobyPrzewlekle;
    }

    /**
     * RECEPTA.CHOROBY_PRZEWLEKLE
     *
     * @param chorobyPrzewlekle
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setChorobyPrzewlekle(UprawnieniaChPrzewlekle chorobyPrzewlekle) {
        this.chorobyPrzewlekle = chorobyPrzewlekle;
    }

    /**
     * @return RECEPTA.DATA_WYSTAWIENIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWystawienia() {
        return dataWystawienia;
    }

    /**
     * RECEPTA.DATA_WYSTAWIENIA
     *
     * @param dataWystawienia
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWystawienia(Date dataWystawienia) {
        this.dataWystawienia = dataWystawienia;
    }

    /**
     * @return RECEPTA.ODDZIAL_NFZ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public OddzialNFZ getOddzialNfz() {
        return oddzialNfz;
    }

    /**
     * RECEPTA.ODDZIAL_NFZ
     *
     * @param oddzialNfz
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOddzialNfz(OddzialNFZ oddzialNfz) {
        this.oddzialNfz = oddzialNfz;
    }

    /**
     * @return RECEPTA.UPRAWNIENIE
     * @mbggenerated 2014-03-13 16:02:38
     */
    public UprawnienieLeki getUprawnienie() {
        return uprawnienie;
    }

    /**
     * RECEPTA.UPRAWNIENIE
     *
     * @param uprawnienie
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setUprawnienie(UprawnienieLeki uprawnienie) {
        this.uprawnienie = uprawnienie;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Recepta other = (Recepta) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaDpsId() == null ? other.getEwidencjaDpsId() == null : this.getEwidencjaDpsId().equals(other.getEwidencjaDpsId()))
            && (this.getLekarzWystawilId() == null ? other.getLekarzWystawilId() == null : this.getLekarzWystawilId().equals(other.getLekarzWystawilId()))
            && (this.getChorobyPrzewlekle() == null ? other.getChorobyPrzewlekle() == null : this.getChorobyPrzewlekle().equals(other.getChorobyPrzewlekle()))
            && (this.getDataWystawienia() == null ? other.getDataWystawienia() == null : this.getDataWystawienia().equals(other.getDataWystawienia()))
            && (this.getOddzialNfz() == null ? other.getOddzialNfz() == null : this.getOddzialNfz().equals(other.getOddzialNfz()))
            && (this.getUprawnienie() == null ? other.getUprawnienie() == null : this.getUprawnienie().equals(other.getUprawnienie()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaDpsId() == null) ? 0 : getEwidencjaDpsId().hashCode());
        result = prime * result + ((getLekarzWystawilId() == null) ? 0 : getLekarzWystawilId().hashCode());
        result = prime * result + ((getChorobyPrzewlekle() == null) ? 0 : getChorobyPrzewlekle().hashCode());
        result = prime * result + ((getDataWystawienia() == null) ? 0 : getDataWystawienia().hashCode());
        result = prime * result + ((getOddzialNfz() == null) ? 0 : getOddzialNfz().hashCode());
        result = prime * result + ((getUprawnienie() == null) ? 0 : getUprawnienie().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaDpsId=").append(ewidencjaDpsId);
        sb.append(", lekarzWystawilId=").append(lekarzWystawilId);
        sb.append(", chorobyPrzewlekle=").append(chorobyPrzewlekle);
        sb.append(", dataWystawienia=").append(dataWystawienia);
        sb.append(", oddzialNfz=").append(oddzialNfz);
        sb.append(", uprawnienie=").append(uprawnienie);
        sb.append("]");
        return sb.toString();
    }
}
